pub struct Sheet {
pub id: String,
pub strands: Vec<Strand>,
pub registration: Vec<Registration>,
}Expand description
Fields
PDB Specification
Overview
SHEET records are used to identify the position of sheets in the molecule. Sheets are both named and numbered. The residues where the sheet begins and ends are noted.
Record Format
| COLUMNS | DATA TYPE | FIELD | DEFINITION |
|---|---|---|---|
| 1 - 6 | Record name | “SHEET “ | |
| 8 - 10 | Integer | strand | Strand number which starts at 1 for each |
| strand within a sheet and increases by one. | |||
| 12 - 14 | LString(3) | sheetID | Sheet identifier. |
| 15 - 16 | Integer | numStrands | Number of strands in sheet. |
| 18 - 20 | Residue name | initResName | Residue name of initial residue. |
| 22 | Character | initChainID | Chain identifier of initial residue |
| in strand. | |||
| 23 - 26 | Integer | initSeqNum | Sequence number of initial residue |
| in strand. | |||
| 27 | AChar | initICode | Insertion code of initial residue |
| in strand. | |||
| 29 - 31 | Residue name | endResName | Residue name of terminal residue. |
| 33 | Character | endChainID | Chain identifier of terminal residue. |
| 34 - 37 | Integer | endSeqNum | Sequence number of terminal residue. |
| 38 | AChar | endICode | Insertion code of terminal residue. |
| 39 - 40 | Integer | sense | Sense of strand with respect to previous |
| strand in the sheet. 0 if first strand, | |||
| 1 if parallel,and -1 if anti-parallel. | |||
| 42 - 45 | Atom | curAtom | Registration. Atom name in current strand. |
| 46 - 48 | Residue name | curResName | Registration. Residue name in current strand |
| 50 | Character | curChainId | Registration. Chain identifier in |
| current strand. | |||
| 51 - 54 | Integer | curResSeq | Registration. Residue sequence number |
| in current strand. | |||
| 55 | AChar | curICode | Registration. Insertion code in |
| current strand. | |||
| 57 - 60 | Atom | prevAtom | Registration. Atom name in previous strand. |
| 61 - 63 | Residue name | prevResName | Registration. Residue name in |
| previous strand. | |||
| 65 | Character | prevChainId | Registration. Chain identifier in |
| previous strand. | |||
| 66 - 69 | Integer | prevResSeq | Registration. Residue sequence number |
| in previous strand. | |||
| 70 | AChar | prevICode | Registration. Insertion code in previous strand. |
Details
- The initial residue for a strand is its N-terminus. Strand registration information is provided in columns 39 - 70. Strands are listed starting with one edge of the sheet and continuing to the spatially adjacent strand.
- The sense in columns 39 - 40 indicates whether strand n is parallel (sense = 1) or anti-parallel (sense = -1) to strand n-1. Sense is equal to zero (0) for the first strand of a sheet.
- The registration (columns 42 - 70) of strand n to strand n-1 may be specified by one hydrogen bond between each such pair of strands. This is done by providing the hydrogen bonding between the current and previous strands. No register information should be provided for the first strand.
- Split strands, or strands with two or more runs of residues from discontinuous parts of the amino acid sequence, are explicitly listed. Detail description can be included in the REMARK 700 .
Fields
id: Stringstrands: Vec<Strand>registration: Vec<Registration>Trait Implementations
Sourceimpl Serialize for Sheet
impl Serialize for Sheet
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more